<?php

namespace Litecms\UserSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\UserSetting\Models\UserSetting;

class UserSettingPolicy
{

    /**
     * Determine if the given user can view the user_setting.
     *
     * @param UserPolicy $user
     * @param UserSetting $user_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, UserSetting $user_setting)
    {
        if ($user->canDo('user_setting.user_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $user_setting->user_id == user_id() && $user_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a user_setting.
     *
     * @param UserPolicy $user
     * @param UserSetting $user_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('user_setting.user_setting.create');
    }

    /**
     * Determine if the given user can update the given user_setting.
     *
     * @param UserPolicy $user
     * @param UserSetting $user_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, UserSetting $user_setting)
    {
        if ($user->canDo('user_setting.user_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $user_setting->user_id == user_id() && $user_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given user_setting.
     *
     * @param UserPolicy $user
     * @param UserSetting $user_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, UserSetting $user_setting)
    {
        return $user_setting->user_id == user_id() && $user_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given user_setting.
     *
     * @param UserPolicy $user
     * @param UserSetting $user_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, UserSetting $user_setting)
    {
        if ($user->canDo('user_setting.user_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given user_setting.
     *
     * @param UserPolicy $user
     * @param UserSetting $user_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, UserSetting $user_setting)
    {
        if ($user->canDo('user_setting.user_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
