<?php

namespace Litecms\UserSetting\Providers;

use Illuminate\Support\ServiceProvider;

class UserSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'user_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'user_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.user_setting', function ($app) {
            return $this->app->make('Litecms\UserSetting\UserSetting');
        });

                // Bind UserSetting to repository
        $this->app->bind(
            'Litecms\UserSetting\Interfaces\UserSettingRepositoryInterface',
            \Litecms\UserSetting\Repositories\Eloquent\UserSettingRepository::class
        );

        $this->app->register(\Litecms\UserSetting\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\UserSetting\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\UserSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.user_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/user_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/user_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/user_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
